This is a library for cryptographic commitment schemes and verification using optimized FFT and hashing functions.
This module provides the functions for commitment generation and verification. It provides the following functions:
commit: to generate a cryptographic commitment.verify: to verify a commitment. Function enhances the verification process by including a random challenge.
You can check repository from github: https://github.com/blueokanna/BlueHash for more details.
Modules
- commit_
error - fft
- This module provides the Fast Fourier Transform (FFT) operations required for matrix multiplication.
- utils
- This module contains utility functions that are used across the project.
Structs
- Reveler
Commit - Struct to hold the commitment point and its corresponding hash.
- Reveler
Result